@@ -80,7 +80,7 @@ void on_button_clicked (GtkWidget *button, gpointer user_data)
 			
 			gtk_widget_hide (table1);
 			image = gtk_image_new ();
-			sprintf(file_name,"%smpuzzle.png",IMAGES_DIR);
+			sprintf(file_name,"%swon.png",IMAGES_DIR);
 			gtk_image_set_from_file (GTK_IMAGE(image), file_name);
 			gtk_object_ref(GTK_OBJECT(table1));
 			gtk_container_remove (GTK_CONTAINER(alignment1), table1);
@@ -109,7 +109,7 @@ GtkWidget* create_main_window (void)
   vacant_pos = 15; move_no=0;
 
   main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (main_window), "MPuzzle-1.2");
+  gtk_window_set_title (GTK_WINDOW (main_window), "MPuzzle-1.3");
   vbox1 = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (main_window), vbox1);
 
